==> libreoffice-6.2.0.3.tar.xz: libreoffice-6.2.0.3/sw/source/ui/chrdlg/tblnumfm.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <svx/svxids.hrc>
#include <svx/numinf.hxx>
#include <swtypes.hxx>
#include <tblnumfm.hxx>

#include <svx/svxdlg.hxx>
#include <svx/dialogs.hrc>
#include <svl/itemset.hxx>
#include <sfx2/tabdlg.hxx>

SwNumFormatDlg::SwNumFormatDlg(weld::Window* pParent, const SfxItemSet& rSet)
    : SfxSingleTabDialogController(pParent, rSet, "cui/ui/formatnumberdialog.ui", "FormatNumberDialog")
{
    // Create TabPage
    SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
    ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc(RID_SVXPAGE_NUMBERFORMAT);
    if ( fnCreatePage )
    {
        TabPageParent pPageParent(get_content_area(), this);
        VclPtr<SfxTabPage> xNewPage = (*fnCreatePage)(pPageParent, &rSet);
        SfxAllItemSet aSet(*(rSet.GetPool()));
        aSet.Put(SvxNumberInfoItem(xNewPage->GetItemSet().Get( SID_ATTR_NUMBERFORMAT_INFO)));
        xNewPage->PageCreated(aSet);
        SetTabPage(xNewPage);
    }
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_6.3.5.orig.tar.xz: libreoffice-6.3.5/sw/source/ui/chrdlg/tblnumfm.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <svx/svxids.hrc>
#include <svx/numinf.hxx>
#include <swtypes.hxx>
#include <tblnumfm.hxx>

#include <svx/svxdlg.hxx>
#include <svx/dialogs.hrc>
#include <svl/itemset.hxx>
#include <sfx2/tabdlg.hxx>

SwNumFormatDlg::SwNumFormatDlg(weld::Widget* pParent, const SfxItemSet& rSet)
    : SfxSingleTabDialogController(pParent, &rSet, "cui/ui/formatnumberdialog.ui", "FormatNumberDialog")
{
    // Create TabPage
    SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
    ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc(RID_SVXPAGE_NUMBERFORMAT);
    if ( fnCreatePage )
    {
        TabPageParent pPageParent(get_content_area(), this);
        VclPtr<SfxTabPage> xNewPage = (*fnCreatePage)(pPageParent, &rSet);
        SfxAllItemSet aSet(*(rSet.GetPool()));
        aSet.Put(xNewPage->GetItemSet().Get( SID_ATTR_NUMBERFORMAT_INFO));
        xNewPage->PageCreated(aSet);
        SetTabPage(xNewPage);
    }
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
